##  Designing a Survey
After defining the scope, you are directed to the Design tab. Designing a survey involves forming the questions and structuring the overall format to gather the necessary information effectively. Here, you have two options for designing your survey:
(a) You can start from scratch and design a new survey.
(b) Alternatively, you can import an existing survey from your workspace or select a survey template available in the SAP LeanIX store to modify and use.
